@@ -88,4 +88,19 @@ def generate_volume_weighted_high_low_vol(lookback_windows, vol_thresholds, up_t
                                     'lag':lag,
                                     'display' : display
                                 })
+    return parameters
+
+
+def generate_volume_weighted_high_low_vol_cont(lookback_windows, contravariants, lags, display):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for lag in lags:
+                if lag <= int(lookback_window/2):
+                    parameters.append({
+                        'lookback_window':lookback_window,
+                        'contravariant':contravariant,
+                        'lag':lag,
+                        'display' : display
+                    })
     return parameters
\ No newline at end of file
